# DBus.ObjectManager implementation for pydbus

This module is based on [seebz/pydbus-manager](https://github.com/seebz/pydbus-manager).

Changes:

* Cache interface metadata
* Rename project
* Publish on PyPI as pydbus-objectmanager.
